@@ -1,7 +1,12 @@
 #include "yahttp.hpp"
 
+#include <limits>
+
 namespace YaHTTP {
 
+  template class AsyncLoader<Request>;
+  template class AsyncLoader<Response>;
+
   bool isspace(char c) {
     return std::isspace(c) != 0;
   }
@@ -170,8 +175,13 @@ namespace YaHTTP {
           buffer.copy(buf, pos);
           buf[pos]=0; // just in case...
           buffer.erase(buffer.begin(), buffer.begin()+pos+1); // remove line from buffer
-          sscanf(buf, "%x", &chunk_size);
+          if (sscanf(buf, "%x", &chunk_size) != 1) {
+            throw ParseError("Unable to parse chunk size");
+          }
           if (chunk_size == 0) { state = 3; break; } // last chunk
+          if (chunk_size > (std::numeric_limits<decltype(chunk_size)>::max() - 2)) {
+            throw ParseError("Chunk is too large");
+          }
         } else {
           int crlf=1;
           if (buffer.size() < static_cast<size_t>(chunk_size+1)) return false; // expect newline
