@@ -66,7 +66,7 @@ void CoWrapper::launch()
     throw ArgException("pipe-command is not specified");
 
   if (isUnixSocket(d_command)) {
-    d_cp = std::make_unique<UnixRemote>(d_command, d_timeout);
+    d_cp = std::make_unique<UnixRemote>(d_command);
   }
   else {
     auto coprocess = std::make_unique<CoProcess>(d_command, d_timeout);
@@ -197,7 +197,7 @@ void PipeBackend::lookup(const QType& qtype, const DNSName& qname, int zoneId, D
   d_qname = qname;
 }
 
-bool PipeBackend::list(const DNSName& target, int inZoneId, bool include_disabled)
+bool PipeBackend::list(const DNSName& target, int inZoneId, bool /* include_disabled */)
 {
   try {
     launch();
@@ -216,7 +216,7 @@ bool PipeBackend::list(const DNSName& target, int inZoneId, bool include_disable
   catch (PDNSException& ae) {
     g_log << Logger::Error << kBackendId << " Error from coprocess: " << ae.reason << endl;
   }
-  d_qname = DNSName(itoa(inZoneId)); // why do we store a number here??
+  d_qname = DNSName(std::to_string(inZoneId)); // why do we store a number here??
   return true;
 }
 
