@@ -76,10 +76,9 @@ void AuthQueryCache::insert(const DNSName &qname, const QType& qtype, vector<DNS
 
   if(!ttl)
     return;
-  
+
   time_t now = time(nullptr);
   CacheEntry val;
-  val.created = now;
   val.ttd = now + ttl;
   val.qname = qname;
   val.qtype = qtype.getCode();
@@ -97,7 +96,7 @@ void AuthQueryCache::insert(const DNSName &qname, const QType& qtype, vector<DNS
 
     bool inserted;
     cmap_t::iterator place;
-    tie(place, inserted) = map->insert(val);
+    std::tie(place, inserted) = map->insert(val);
 
     if (!inserted) {
       map->replace(place, std::move(val));
@@ -119,7 +118,7 @@ void AuthQueryCache::insert(const DNSName &qname, const QType& qtype, vector<DNS
 bool AuthQueryCache::getEntryLocked(const cmap_t& map, const DNSName &qname, uint16_t qtype, vector<DNSZoneRecord>& value, int zoneID, time_t now)
 {
   auto& idx = boost::multi_index::get<HashTag>(map);
-  auto iter = idx.find(tie(qname, qtype, zoneID));
+  auto iter = idx.find(std::tie(qname, qtype, zoneID));
 
   if (iter == idx.end()) {
     (*d_statnummiss)++;
