@@ -73,6 +73,7 @@ const map<const string, uint16_t> QType::names = {
   {"CDNSKEY", 60},
   {"OPENPGPKEY", 61},
   {"CSYNC", 62},
+  {"ZONEMD", 63},
   {"SVCB", 64},
   {"HTTPS", 65},
   {"SPF", 99},
@@ -93,8 +94,10 @@ const map<const string, uint16_t> QType::names = {
   {"CAA", 257},
   {"DLV", 32769},
   {"ADDR", 65400},
+#if !defined(RECURSOR)
   {"ALIAS", 65401},
   {"LUA", 65402},
+#endif
 };
 
 static map<uint16_t, const string> swapElements(const map<const string, uint16_t>& names) {
@@ -132,7 +135,7 @@ const string QType::toString() const
   if (name != numbers.cend()) {
     return name->second;
   }
-  return "TYPE" + itoa(code);
+  return "TYPE" + std::to_string(code);
 }
 
 uint16_t QType::chartocode(const char *p)
