@@ -16,24 +16,24 @@ BOOST_AUTO_TEST_SUITE(test_ipcrypt_hh)
 
 BOOST_AUTO_TEST_CASE(test_ipcrypt4)
 {
-  ComboAddress ca("127.0.0.1");
-  std::string key="0123456789ABCDEF";
-  auto encrypted = encryptCA(ca, key);
+  ComboAddress address("127.0.0.1");
+  std::string key = "0123456789ABCDEF";
+  auto encrypted = encryptCA(address, key);
 
   auto decrypted = decryptCA(encrypted, key);
-  BOOST_CHECK_EQUAL(ca.toString(), decrypted.toString());
+  BOOST_CHECK_EQUAL(address.toString(), decrypted.toString());
 }
 
 BOOST_AUTO_TEST_CASE(test_ipcrypt4_vector)
 {
-  vector<pair<string,string>>  tests{   // test vector from https://github.com/veorq/ipcrypt
-    {{"127.0.0.1"},{"114.62.227.59"}},
-    {{"8.8.8.8"},  {"46.48.51.50"}},
-    {{"1.2.3.4"},  {"171.238.15.199"}}};
+  // test vector from https://github.com/veorq/ipcrypt
+  vector<pair<string, string>> tests{{{"127.0.0.1"}, {"114.62.227.59"}},
+                                     {{"8.8.8.8"}, {"46.48.51.50"}},
+                                     {{"1.2.3.4"}, {"171.238.15.199"}}};
 
-  std::string key="some 16-byte key";
+  std::string key = "some 16-byte key";
 
-  for(const auto& p : tests) {
+  for (const auto& p : tests) {
     auto encrypted = encryptCA(ComboAddress(p.first), key);
     BOOST_CHECK_EQUAL(encrypted.toString(), p.second);
     auto decrypted = decryptCA(encrypted, key);
@@ -41,32 +41,34 @@ BOOST_AUTO_TEST_CASE(test_ipcrypt4_vector)
   }
 
   // test from Frank Denis' test.cc
-  ComboAddress ip("192.168.69.42"), out, dec;
+  ComboAddress address("192.168.69.42");
+  ComboAddress out;
+  ComboAddress dec;
   string key2;
-  for(int n=0; n<16; ++n)
-    key2.append(1, (char)n+1);
+  for (int n = 0; n < 16; ++n) {
+    key2.append(1, (char)n + 1);
+  }
 
   for (unsigned int i = 0; i < 100000000UL; i++) {
-    out=encryptCA(ip, key2);
+    out = encryptCA(address, key2);
     //    dec=decryptCA(out, key2);
     // BOOST_CHECK(ip==dec);
-    ip=out;
+    address = out;
   }
 
   ComboAddress expected("93.155.197.186");
 
-  BOOST_CHECK_EQUAL(ip.toString(), expected.toString());
+  BOOST_CHECK_EQUAL(address.toString(), expected.toString());
 }
 
-
 BOOST_AUTO_TEST_CASE(test_ipcrypt6)
 {
-  ComboAddress ca("::1");
-  std::string key="0123456789ABCDEF";
-  auto encrypted = encryptCA(ca, key);
+  ComboAddress address("::1");
+  std::string key = "0123456789ABCDEF";
+  auto encrypted = encryptCA(address, key);
 
   auto decrypted = decryptCA(encrypted, key);
-  BOOST_CHECK_EQUAL(ca.toString(), decrypted.toString());
+  BOOST_CHECK_EQUAL(address.toString(), decrypted.toString());
 }
 
 BOOST_AUTO_TEST_SUITE_END()
